# SLOPpy
## Spectral Lines Of Planets with python
<!---
## the ultimate tool for exoplanet characterization
--->

<!---
[![GitHub][github-badge]][github-link]
--->

``SLOPpy`` is a robust, versatile framework for the characterization of atmospheres of planetary systems.

Every information you need to analyze your data is contained in an easy-to-use and portable configuration file in the ``yaml`` format.


```{admonition} Be careful
Documentation is still work in progress!
```

## Table of contents

```{toctree}
:maxdepth: 2
installation
configuration_file
reduction_steps
GitHub Repository <https://github.com/LucaMalavolta/SLOPpy>
```

<!---
```{eval-rst}
.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   prepare_datasets
   prepare_yaml
   api
```
--->

<!---

..
  Following `PEP 8 Style Guide for Python Code <https://www.python.org/dev/peps/pep-0008/>`_  ,
  `PEP 257 Docstring Conventions <https://www.python.org/dev/peps/pep-0257/>`_ and `Google Python Style Guide <http://google.github.io/styleguide/pyguide.html>`_

..
  Indices and tables
  ==================

  * :ref:`genindex`
  * :ref:`modindex`
  * :ref:`search`

--->

This documentation has been rendered using the [Sphinx Book Theme](https://sphinx-book-theme.readthedocs.io/) and the [Myst parser](https://myst-parser.readthedocs.io/)
